.. _sec_installation:

============
Installation
============

Tszip can be installed using the standard `pip <https://pypi.org/project/pip/>`_ and
`conda <https://docs.conda.io/en/latest/>`_ distribution methods.

For pip users, run::

    $ python3 -m pip install tszip

For conda users, tszip is distributed using the `conda-forge <https://conda-forge.org/>`_
channel. To install, either ensure that conda-forge is listed in your default channels
and run::

    $ conda install tszip

or explicitly install from conda-forge::


    $ conda install -c conda-forge tszip
